@@ -23,8 +23,8 @@ print.seqmulti <- function(x, ...){
   if (x$is_stopped == TRUE){
     cat('The sample selection process is finished. \n')
     cat('The final result is shown below:','\n')
-    cat("The length of fixed size confidence set (dlen):", x$d,'\n')
-    cat("The number of samples at the end of iteration:",x$N,'\n')
+    cat("The length of fixed size confidence set (d):", x$d,'\n')
+    cat("The number of samples at the end of iteration:",x$n,'\n')
     cat('The estimated coefficient at the end of iteration:',paste(round(x$beta_est,5),' '),'\n')
   }
   if (x$is_stopped == FALSE){
